@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Template Programmer API wrapper.
+"""Cisco DNA Center Template Programmer API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class TemplateProgrammer(object):
-    """DNA Center Template Programmer API (version: 1.2.10).
+    """Cisco DNA Center Template Programmer API (version: 1.2.10).
 
     Wraps the DNA Center Template Programmer
     API and exposes the API as native Python
@@ -87,16 +87,11 @@ class TemplateProgrammer(object):
         Args:
             project_id(basestring): projectId query parameter.
             software_type(basestring): softwareType query parameter.
-            software_version(basestring): softwareVersion query
-                parameter.
-            product_family(basestring): productFamily query
-                parameter.
-            product_series(basestring): productSeries query
-                parameter.
+            software_version(basestring): softwareVersion query parameter.
+            product_family(basestring): productFamily query parameter.
+            product_series(basestring): productSeries query parameter.
             product_type(basestring): productType query parameter.
-            filter_conflicting_templates(bool):
-                filterConflictingTemplates query
-                parameter.
+            filter_conflicting_templates(bool): filterConflictingTemplates query parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -183,8 +178,7 @@ class TemplateProgrammer(object):
             lastUpdateTime(number): ProjectDTO's lastUpdateTime.
             name(string): ProjectDTO's name.
             tags(list): ProjectDTO's tags (list of string, objects).
-            templates: Part of the JSON serializable Python object
-                to send in the body of the Request.
+            templates: Part of the JSON serializable Python object to send in the body of the Request.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -293,38 +287,27 @@ class TemplateProgrammer(object):
         Args:
             author(string): TemplateDTO's author.
             composite(boolean): TemplateDTO's composite.
-            containingTemplates(list): TemplateDTO's
-                containingTemplates (list of objects).
+            containingTemplates(list): TemplateDTO's containingTemplates (list of objects).
             createTime(number): TemplateDTO's createTime.
             description(string): TemplateDTO's description.
-            deviceTypes(list): TemplateDTO's deviceTypes (list of
-                objects).
-            failurePolicy(string): TemplateDTO's failurePolicy.
-                Available values are 'ABORT_ON_ERROR',
-                'CONTINUE_ON_ERROR',
-                'ROLLBACK_ON_ERROR',
-                'ROLLBACK_TARGET_ON_ERROR' and
+            deviceTypes(list): TemplateDTO's deviceTypes (list of objects).
+            failurePolicy(string): TemplateDTO's failurePolicy. Available values are 'ABORT_ON_ERROR',
+                'CONTINUE_ON_ERROR', 'ROLLBACK_ON_ERROR', 'ROLLBACK_TARGET_ON_ERROR' and
                 'ABORT_TARGET_ON_ERROR'.
             id(string): TemplateDTO's id.
             lastUpdateTime(number): TemplateDTO's lastUpdateTime.
             name(string): TemplateDTO's name.
-            parentTemplateId(string): TemplateDTO's
-                parentTemplateId.
+            parentTemplateId(string): TemplateDTO's parentTemplateId.
             projectId(string): TemplateDTO's projectId.
             projectName(string): TemplateDTO's projectName.
-            rollbackTemplateContent(string): TemplateDTO's
-                rollbackTemplateContent.
-            rollbackTemplateParams(list): TemplateDTO's
-                rollbackTemplateParams (list of
-                objects).
+            rollbackTemplateContent(string): TemplateDTO's rollbackTemplateContent.
+            rollbackTemplateParams(list): TemplateDTO's rollbackTemplateParams (list of objects).
             softwareType(string): TemplateDTO's softwareType.
             softwareVariant(string): TemplateDTO's softwareVariant.
             softwareVersion(string): TemplateDTO's softwareVersion.
-            tags(list): TemplateDTO's tags (list of string,
-                objects).
+            tags(list): TemplateDTO's tags (list of string, objects).
             templateContent(string): TemplateDTO's templateContent.
-            templateParams(list): TemplateDTO's templateParams (list
-                of objects).
+            templateParams(list): TemplateDTO's templateParams (list of objects).
             version(string): TemplateDTO's version.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
@@ -502,18 +485,12 @@ class TemplateProgrammer(object):
         """Deploys a template.
 
         Args:
-            forcePushTemplate(boolean): TemplateDeploymentInfo's
-                forcePushTemplate.
-            isComposite(boolean): TemplateDeploymentInfo's
-                isComposite.
-            mainTemplateId(string): TemplateDeploymentInfo's
-                mainTemplateId.
-            memberTemplateDeploymentInfo(list):
-                TemplateDeploymentInfo's
-                memberTemplateDeploymentInfo (list of
-                any objects).
-            targetInfo(list): TemplateDeploymentInfo's targetInfo
-                (list of objects).
+            forcePushTemplate(boolean): TemplateDeploymentInfo's forcePushTemplate.
+            isComposite(boolean): TemplateDeploymentInfo's isComposite.
+            mainTemplateId(string): TemplateDeploymentInfo's mainTemplateId.
+            memberTemplateDeploymentInfo(list): TemplateDeploymentInfo's memberTemplateDeploymentInfo (list of any
+                objects).
+            targetInfo(list): TemplateDeploymentInfo's targetInfo (list of objects).
             templateId(string): TemplateDeploymentInfo's templateId.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
@@ -671,8 +648,7 @@ class TemplateProgrammer(object):
             lastUpdateTime(number): ProjectDTO's lastUpdateTime.
             name(string): ProjectDTO's name.
             tags(list): ProjectDTO's tags (list of string, objects).
-            templates: Part of the JSON serializable Python object
-                to send in the body of the Request.
+            templates: Part of the JSON serializable Python object to send in the body of the Request.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -872,8 +848,7 @@ class TemplateProgrammer(object):
 
         Args:
             comments(string): TemplateVersionRequestDTO's comments.
-            templateId(string): TemplateVersionRequestDTO's
-                templateId.
+            templateId(string): TemplateVersionRequestDTO's templateId.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -951,8 +926,7 @@ class TemplateProgrammer(object):
 
         Args:
             params(object): TemplatePreviewRequestDTO's params.
-            templateId(string): TemplatePreviewRequestDTO's
-                templateId.
+            templateId(string): TemplatePreviewRequestDTO's templateId.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -1108,38 +1082,27 @@ class TemplateProgrammer(object):
         Args:
             author(string): TemplateDTO's author.
             composite(boolean): TemplateDTO's composite.
-            containingTemplates(list): TemplateDTO's
-                containingTemplates (list of objects).
+            containingTemplates(list): TemplateDTO's containingTemplates (list of objects).
             createTime(number): TemplateDTO's createTime.
             description(string): TemplateDTO's description.
-            deviceTypes(list): TemplateDTO's deviceTypes (list of
-                objects).
-            failurePolicy(string): TemplateDTO's failurePolicy.
-                Available values are 'ABORT_ON_ERROR',
-                'CONTINUE_ON_ERROR',
-                'ROLLBACK_ON_ERROR',
-                'ROLLBACK_TARGET_ON_ERROR' and
+            deviceTypes(list): TemplateDTO's deviceTypes (list of objects).
+            failurePolicy(string): TemplateDTO's failurePolicy. Available values are 'ABORT_ON_ERROR',
+                'CONTINUE_ON_ERROR', 'ROLLBACK_ON_ERROR', 'ROLLBACK_TARGET_ON_ERROR' and
                 'ABORT_TARGET_ON_ERROR'.
             id(string): TemplateDTO's id.
             lastUpdateTime(number): TemplateDTO's lastUpdateTime.
             name(string): TemplateDTO's name.
-            parentTemplateId(string): TemplateDTO's
-                parentTemplateId.
+            parentTemplateId(string): TemplateDTO's parentTemplateId.
             projectId(string): TemplateDTO's projectId.
             projectName(string): TemplateDTO's projectName.
-            rollbackTemplateContent(string): TemplateDTO's
-                rollbackTemplateContent.
-            rollbackTemplateParams(list): TemplateDTO's
-                rollbackTemplateParams (list of
-                objects).
+            rollbackTemplateContent(string): TemplateDTO's rollbackTemplateContent.
+            rollbackTemplateParams(list): TemplateDTO's rollbackTemplateParams (list of objects).
             softwareType(string): TemplateDTO's softwareType.
             softwareVariant(string): TemplateDTO's softwareVariant.
             softwareVersion(string): TemplateDTO's softwareVersion.
-            tags(list): TemplateDTO's tags (list of string,
-                objects).
+            tags(list): TemplateDTO's tags (list of string, objects).
             templateContent(string): TemplateDTO's templateContent.
-            templateParams(list): TemplateDTO's templateParams (list
-                of objects).
+            templateParams(list): TemplateDTO's templateParams (list of objects).
             version(string): TemplateDTO's version.
             project_id(basestring): projectId path parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
