@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center SWIM API wrapper.
+"""Cisco DNA Center SWIM API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class Swim(object):
-    """DNA Center SWIM API (version: 1.2.10).
+    """Cisco DNA Center SWIM API (version: 1.3.0).
 
     Wraps the DNA Center SWIM
     API and exposes the API as native Python
@@ -100,10 +100,8 @@ class Swim(object):
             image_uuid(basestring): imageUuid query parameter.
             name(basestring): name query parameter.
             family(basestring): family query parameter.
-            application_type(basestring): applicationType query
-                parameter.
-            image_integrity_status(basestring): imageIntegrityStatus
-                - FAILURE, UNKNOWN, VERIFIED.
+            application_type(basestring): applicationType query parameter.
+            image_integrity_status(basestring): imageIntegrityStatus FAILURE, UNKNOWN, VERIFIED.
             version(basestring): software Image Version.
             image_series(basestring): image Series.
             image_name(basestring): image Name.
@@ -114,8 +112,7 @@ class Swim(object):
             image_size_greater_than(int): size in bytes.
             image_size_lesser_than(int): size in bytes.
             sort_by(basestring): sort results by this field.
-            sort_order(basestring): sort order - 'asc' or 'des'.
-                Default is asc.
+            sort_order(basestring): sort order 'asc' or 'des'. Default is asc.
             limit(int): limit query parameter.
             offset(int): offset query parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -214,7 +211,7 @@ class Swim(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_0c8f7a0b49b9aedd_v1_2_10', json_data)
+        return self._object_factory('bpm_0c8f7a0b49b9aedd_v1_3_0', json_data)
 
     def trigger_software_image_distribution(self,
                                             headers=None,
@@ -264,7 +261,7 @@ class Swim(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_8cb6783b4faba1f4_v1_2_10')\
+            self._request_validator('jsd_8cb6783b4faba1f4_v1_3_0')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -283,7 +280,7 @@ class Swim(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_8cb6783b4faba1f4_v1_2_10', json_data)
+        return self._object_factory('bpm_8cb6783b4faba1f4_v1_3_0', json_data)
 
     def import_local_software_image(self,
                                     multipart_fields,
@@ -299,7 +296,10 @@ class Swim(object):
         are bin, img, tar, smu, pie, aes, iso, ova, tar_gz and
         qcow2.
 
-        The following code gives an example of the multipart_fields.
+        The following code gives an **example** of the multipart_fields,
+        using `file` and `images` as form data field.
+
+        Use the appropiate form data field for the function.
 
         .. code-block:: python
 
@@ -329,10 +329,8 @@ class Swim(object):
         Args:
             is_third_party(bool): Third party Image check.
             third_party_vendor(basestring): Third Party Vendor.
-            third_party_image_family(basestring): Third Party image
-                family.
-            third_party_application_type(basestring): Third Party
-                Application Type.
+            third_party_image_family(basestring): Third Party image family.
+            third_party_application_type(basestring): Third Party Application Type.
             multipart_fields(dict): Fields from which to create a
                 multipart/form-data body.
             multipart_monitor_callback(function): function used to monitor
@@ -350,8 +348,6 @@ class Swim(object):
             TypeError: If the parameter types are incorrect.
             MalformedRequest: If the request body created is invalid.
             ApiError: If the DNA Center cloud returns an error.
-            DownloadFailure: If was not able to download the raw
-            response to a file.
         """
         check_type(headers, dict)
         check_type(is_third_party, bool)
@@ -403,97 +399,7 @@ class Swim(object):
         else:
             json_data = self._session.post(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_4dbe3bc743a891bc_v1_2_10', json_data)
-
-    def import_software_image_via_url(self,
-                                      schedule_at=None,
-                                      schedule_desc=None,
-                                      schedule_origin=None,
-                                      headers=None,
-                                      payload=None,
-                                      active_validation=True,
-                                      **request_parameters):
-        """Fetches a software image from remote file system (using URL for
-        HTTP/FTP) and uploads to DNA Center. Supported image
-        files extensions are bin, img, tar, smu, pie, aes, iso,
-        ova, tar_gz and qcow2.
-
-        Args:
-            schedule_at(basestring): Epoch Time (The number of
-                milli-seconds since January 1 1970 UTC)
-                at which the distribution should be
-                scheduled (Optional) .
-            schedule_desc(basestring): Custom Description
-                (Optional).
-            schedule_origin(basestring): Originator of this call
-                (Optional).
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        check_type(schedule_at, basestring)
-        check_type(schedule_desc, basestring)
-        check_type(schedule_origin, basestring)
-        if headers is not None:
-            if 'Content-Type' in headers:
-                check_type(headers.get('Content-Type'),
-                           basestring, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'scheduleAt':
-                schedule_at,
-            'scheduleDesc':
-                schedule_desc,
-            'scheduleOrigin':
-                schedule_origin,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_bc8aab4746ca883d_v1_2_10')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/image/importation/source/url')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_bc8aab4746ca883d_v1_2_10', json_data)
+        return self._object_factory('bpm_4dbe3bc743a891bc_v1_3_0', json_data)
 
     def trigger_software_image_activation(self,
                                           schedule_validate=None,
@@ -505,8 +411,7 @@ class Swim(object):
         must be present in the device flash.
 
         Args:
-            schedule_validate(bool): scheduleValidate, validates
-                data before schedule (Optional).
+            schedule_validate(bool): scheduleValidate, validates data before schedule (Optional).
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(list): A JSON serializable Python object to send in the
@@ -554,7 +459,7 @@ class Swim(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_fb9beb664f2aba4c_v1_2_10')\
+            self._request_validator('jsd_fb9beb664f2aba4c_v1_3_0')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -573,4 +478,90 @@ class Swim(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_fb9beb664f2aba4c_v1_2_10', json_data)
+        return self._object_factory('bpm_fb9beb664f2aba4c_v1_3_0', json_data)
+
+    def import_software_image_via_url(self,
+                                      schedule_at=None,
+                                      schedule_desc=None,
+                                      schedule_origin=None,
+                                      headers=None,
+                                      payload=None,
+                                      active_validation=True,
+                                      **request_parameters):
+        """Fetches a software image from remote file system (using URL for
+        HTTP/FTP) and uploads to DNA Center. Supported image
+        files extensions are bin, img, tar, smu, pie, aes, iso,
+        ova, tar_gz and qcow2.
+
+        Args:
+            schedule_at(basestring): Epoch Time (The number of milli-seconds since January 1 1970 UTC) at which the
+                distribution should be scheduled (Optional) .
+            schedule_desc(basestring): Custom Description (Optional).
+            schedule_origin(basestring): Originator of this call (Optional).
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, list)
+        check_type(schedule_at, basestring)
+        check_type(schedule_desc, basestring)
+        check_type(schedule_origin, basestring)
+        if headers is not None:
+            if 'Content-Type' in headers:
+                check_type(headers.get('Content-Type'),
+                           basestring, may_be_none=False)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+            'scheduleAt':
+                schedule_at,
+            'scheduleDesc':
+                schedule_desc,
+            'scheduleOrigin':
+                schedule_origin,
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_bc8aab4746ca883d_v1_3_0')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/image/importation/source/url')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_bc8aab4746ca883d_v1_3_0', json_data)
