@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Task API wrapper.
+"""Cisco DNA Center Task API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class Task(object):
-    """DNA Center Task API (version: 1.3.3).
+    """Cisco DNA Center Task API (version: 2.1.1).
 
     Wraps the DNA Center Task
     API and exposes the API as native Python
@@ -88,24 +88,16 @@ class Task(object):
         """Returns Task count.
 
         Args:
-            start_time(basestring): This is the epoch start time
-                from which tasks need to be fetched.
-            end_time(basestring): This is the epoch end time upto
-                which audit records need to be fetched.
+            start_time(basestring): This is the epoch start time from which tasks need to be fetched.
+            end_time(basestring): This is the epoch end time upto which audit records need to be fetched.
             data(basestring): Fetch tasks that contains this data.
-            error_code(basestring): Fetch tasks that have this error
-                code.
-            service_type(basestring): Fetch tasks with this service
-                type.
+            error_code(basestring): Fetch tasks that have this error code.
+            service_type(basestring): Fetch tasks with this service type.
             username(basestring): Fetch tasks with this username.
-            progress(basestring): Fetch tasks that contains this
-                progress.
-            is_error(basestring): Fetch tasks ended as success or
-                failure. Valid values: true, false.
-            failure_reason(basestring): Fetch tasks that contains
-                this failure reason.
-            parent_id(basestring): Fetch tasks that have this parent
-                Id.
+            progress(basestring): Fetch tasks that contains this progress.
+            is_error(basestring): Fetch tasks ended as success or failure. Valid values: true, false.
+            failure_reason(basestring): Fetch tasks that contains this failure reason.
+            parent_id(basestring): Fetch tasks that have this parent Id.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -178,7 +170,7 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_26b44ab04649a183_v1_3_3', json_data)
+        return self._object_factory('bpm_26b44ab04649a183_v2_1_1', json_data)
 
     def get_task_by_id(self,
                        task_id,
@@ -233,130 +225,7 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_a1a9387346ba92b1_v1_3_3', json_data)
-
-    def get_task_by_operationid(self,
-                                limit,
-                                offset,
-                                operation_id,
-                                headers=None,
-                                **request_parameters):
-        """Returns root tasks associated with an Operationid.
-
-        Args:
-            operation_id(basestring): operationId path parameter.
-            offset(int): Index, minimum value is 0.
-            limit(int): The maximum value of {limit} supported is
-                500.              Base 1 indexing for
-                {limit}, minimum value is 1.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(operation_id, basestring,
-                   may_be_none=False)
-        check_type(offset, int,
-                   may_be_none=False)
-        check_type(limit, int,
-                   may_be_none=False)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'operationId': operation_id,
-            'offset': offset,
-            'limit': limit,
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/task/operation/${operationId}/${offse'
-                 + 't}/${limit}')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_e487f8d3481b94f2_v1_3_3', json_data)
-
-    def get_task_tree(self,
-                      task_id,
-                      headers=None,
-                      **request_parameters):
-        """Returns a task with its children tasks by based on their id.
-
-        Args:
-            task_id(basestring): UUID of the Task.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(task_id, basestring,
-                   may_be_none=False)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-            'taskId': task_id,
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/task/${taskId}/tree')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_f5a269c44f2a95fa_v1_3_3', json_data)
+        return self._object_factory('bpm_a1a9387346ba92b1_v2_1_1', json_data)
 
     def get_tasks(self,
                   data=None,
@@ -378,28 +247,20 @@ class Task(object):
         """Returns task(s) based on filter criteria.
 
         Args:
-            start_time(basestring): This is the epoch start time
-                from which tasks need to be fetched.
-            end_time(basestring): This is the epoch end time upto
-                which audit records need to be fetched.
+            start_time(basestring): This is the epoch start time from which tasks need to be fetched.
+            end_time(basestring): This is the epoch end time upto which audit records need to be fetched.
             data(basestring): Fetch tasks that contains this data.
-            error_code(basestring): Fetch tasks that have this error
-                code.
-            service_type(basestring): Fetch tasks with this service
-                type.
+            error_code(basestring): Fetch tasks that have this error code.
+            service_type(basestring): Fetch tasks with this service type.
             username(basestring): Fetch tasks with this username.
-            progress(basestring): Fetch tasks that contains this
-                progress.
-            is_error(basestring): Fetch tasks ended as success or
-                failure. Valid values: true, false.
-            failure_reason(basestring): Fetch tasks that contains
-                this failure reason.
-            parent_id(basestring): Fetch tasks that have this parent
-                Id.
+            progress(basestring): Fetch tasks that contains this progress.
+            is_error(basestring): Fetch tasks ended as success or failure. Valid values: true, false.
+            failure_reason(basestring): Fetch tasks that contains this failure reason.
+            parent_id(basestring): Fetch tasks that have this parent Id.
             offset(basestring): offset query parameter.
             limit(basestring): limit query parameter.
             sort_by(basestring): Sort results by this field.
-            order(basestring): Sort order - asc or dsc.
+            order(basestring): Sort order asc or dsc.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -484,4 +345,126 @@ class Task(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e78bb8a2449b9eed_v1_3_3', json_data)
+        return self._object_factory('bpm_e78bb8a2449b9eed_v2_1_1', json_data)
+
+    def get_task_tree(self,
+                      task_id,
+                      headers=None,
+                      **request_parameters):
+        """Returns a task with its children tasks by based on their id.
+
+        Args:
+            task_id(basestring): UUID of the Task.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(task_id, basestring,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'taskId': task_id,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/task/${taskId}/tree')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_f5a269c44f2a95fa_v2_1_1', json_data)
+
+    def get_task_by_operationid(self,
+                                limit,
+                                offset,
+                                operation_id,
+                                headers=None,
+                                **request_parameters):
+        """Returns root tasks associated with an Operationid.
+
+        Args:
+            operation_id(basestring): operationId path parameter.
+            offset(int): Index, minimum value is 0.
+            limit(int): The maximum value of {limit} supported is 500.               Base 1 indexing for {limit},
+                minimum value is 1.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(operation_id, basestring,
+                   may_be_none=False)
+        check_type(offset, int,
+                   may_be_none=False)
+        check_type(limit, int,
+                   may_be_none=False)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+            'operationId': operation_id,
+            'offset': offset,
+            'limit': limit,
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/task/operation/${operationId}/${offse'
+                 + 't}/${limit}')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_e487f8d3481b94f2_v2_1_1', json_data)
