@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Device Replacement API wrapper.
+"""Cisco DNA Center Device Replacement API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class DeviceReplacement(object):
-    """DNA Center Device Replacement API (version: 2.2.1).
+    """Cisco DNA Center Device Replacement API (version: 2.1.2).
 
     Wraps the DNA Center Device Replacement
     API and exposes the API as native Python
@@ -72,89 +72,6 @@ class DeviceReplacement(object):
         self._object_factory = object_factory
         self._request_validator = request_validator
 
-    def deploy_device_replacement_workflow(self,
-                                           faultyDeviceSerialNumber=None,
-                                           replacementDeviceSerialNumber=None,
-                                           headers=None,
-                                           payload=None,
-                                           active_validation=True,
-                                           **request_parameters):
-        """API to trigger RMA workflow that will replace faulty device with
-        replacement device with same configuration and images.
-
-        Args:
-            faultyDeviceSerialNumber(string):
-                DeviceReplacementWorkflowDTO's
-                faultyDeviceSerialNumber.
-            replacementDeviceSerialNumber(string):
-                DeviceReplacementWorkflowDTO's
-                replacementDeviceSerialNumber.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'Content-Type' in headers:
-                check_type(headers.get('Content-Type'),
-                           basestring, may_be_none=False)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'faultyDeviceSerialNumber':
-                faultyDeviceSerialNumber,
-            'replacementDeviceSerialNumber':
-                replacementDeviceSerialNumber,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_3faaa9944b49bc9f_v2_2_1')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/device-replacement/workflow')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_3faaa9944b49bc9f_v2_2_1', json_data)
-
     def unmark_device_for_replacement(self,
                                       headers=None,
                                       payload=None,
@@ -201,7 +118,7 @@ class DeviceReplacement(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_4ababa75489ab24b_v2_2_1')\
+            self._request_validator('jsd_4ababa75489ab24b_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -220,7 +137,86 @@ class DeviceReplacement(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_4ababa75489ab24b_v2_2_1', json_data)
+        return self._object_factory('bpm_4ababa75489ab24b_v2_1_2', json_data)
+
+    def deploy_device_replacement_workflow(self,
+                                           faultyDeviceSerialNumber=None,
+                                           replacementDeviceSerialNumber=None,
+                                           headers=None,
+                                           payload=None,
+                                           active_validation=True,
+                                           **request_parameters):
+        """API to trigger RMA workflow that will replace faulty device with
+        replacement device with same configuration and images.
+
+        Args:
+            faultyDeviceSerialNumber(string): DeviceReplacementWorkflowDTO's faultyDeviceSerialNumber.
+            replacementDeviceSerialNumber(string): DeviceReplacementWorkflowDTO's replacementDeviceSerialNumber.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'Content-Type' in headers:
+                check_type(headers.get('Content-Type'),
+                           basestring, may_be_none=False)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = {
+            'faultyDeviceSerialNumber':
+                faultyDeviceSerialNumber,
+            'replacementDeviceSerialNumber':
+                replacementDeviceSerialNumber,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_3faaa9944b49bc9f_v2_1_2')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/device-replacement/workflow')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload,
+                                           headers=_headers)
+        else:
+            json_data = self._session.post(endpoint_full_url, params=_params,
+                                           json=_payload)
+
+        return self._object_factory('bpm_3faaa9944b49bc9f_v2_1_2', json_data)
 
     def mark_device_for_replacement(self,
                                     headers=None,
@@ -268,7 +264,7 @@ class DeviceReplacement(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_64b9dad0403aaca1_v2_2_1')\
+            self._request_validator('jsd_64b9dad0403aaca1_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -287,7 +283,7 @@ class DeviceReplacement(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_64b9dad0403aaca1_v2_2_1', json_data)
+        return self._object_factory('bpm_64b9dad0403aaca1_v2_1_2', json_data)
 
     def return_replacement_devices_with_details(self,
                                                 family=None,
@@ -312,24 +308,15 @@ class DeviceReplacement(object):
 
         Args:
             faulty_device_name(basestring): Faulty Device Name.
-            faulty_device_platform(basestring): Faulty Device
-                Platform.
-            replacement_device_platform(basestring): Replacement
-                Device Platform.
-            faulty_device_serial_number(basestring): Faulty Device
-                Serial Number.
-            replacement_device_serial_number(basestring):
-                Replacement Device Serial Number.
-            replacement_status(basestring): Device Replacement
-                status [READY-FOR-REPLACEMENT,
-                REPLACEMENT-IN-PROGRESS, REPLACEMENT-
-                SCHEDULED, REPLACED, ERROR,
-                NETWORK_READINESS_REQUESTED,
-                NETWORK_READINESS_FAILED].
-            family(basestring): List of families[Routers, Switches
-                and Hubs, AP].
-            sort_by(basestring): SortBy this field. SortBy is
-                mandatory when order is used.
+            faulty_device_platform(basestring): Faulty Device Platform.
+            replacement_device_platform(basestring): Replacement Device Platform.
+            faulty_device_serial_number(basestring): Faulty Device Serial Number.
+            replacement_device_serial_number(basestring): Replacement Device Serial Number.
+            replacement_status(basestring, list, set, tuple): Device Replacement status [READY-FOR-REPLACEMENT,
+                REPLACEMENT-IN-PROGRESS, REPLACEMENT-SCHEDULED, REPLACED, ERROR,
+                NETWORK_READINESS_REQUESTED, NETWORK_READINESS_FAILED].
+            family(basestring, list, set, tuple): List of families[Routers, Switches and Hubs, AP].
+            sort_by(basestring): SortBy this field. SortBy is mandatory when order is used.
             sort_order(basestring): Order on displayName[ASC,DESC].
             offset(int): offset query parameter.
             limit(int): limit query parameter.
@@ -353,8 +340,8 @@ class DeviceReplacement(object):
         check_type(replacement_device_platform, basestring)
         check_type(faulty_device_serial_number, basestring)
         check_type(replacement_device_serial_number, basestring)
-        check_type(replacement_status, basestring)
-        check_type(family, basestring)
+        check_type(replacement_status, (basestring, list, set, tuple))
+        check_type(family, (basestring, list, set, tuple))
         check_type(sort_by, basestring)
         check_type(sort_order, basestring)
         check_type(offset, int)
@@ -408,7 +395,7 @@ class DeviceReplacement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_809c29564bc997d0_v2_2_1', json_data)
+        return self._object_factory('bpm_809c29564bc997d0_v2_1_2', json_data)
 
     def return_replacement_devices_count(self,
                                          replacement_status=None,
@@ -417,10 +404,8 @@ class DeviceReplacement(object):
         """Get replacement devices count.
 
         Args:
-            replacement_status(basestring): Device Replacement
-                status list[READY-FOR-REPLACEMENT,
-                REPLACEMENT-IN-PROGRESS, REPLACEMENT-
-                SCHEDULED, REPLACED, ERROR].
+            replacement_status(basestring, list, set, tuple): Device Replacement status list[READY-FOR-REPLACEMENT,
+                REPLACEMENT-IN-PROGRESS, REPLACEMENT-SCHEDULED, REPLACED, ERROR].
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -436,7 +421,7 @@ class DeviceReplacement(object):
             ApiError: If the DNA Center cloud returns an error.
         """
         check_type(headers, dict)
-        check_type(replacement_status, basestring)
+        check_type(replacement_status, (basestring, list, set, tuple))
         if headers is not None:
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
@@ -466,4 +451,4 @@ class DeviceReplacement(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_9eb84ba54929a2a2_v2_2_1', json_data)
+        return self._object_factory('bpm_9eb84ba54929a2a2_v2_1_2', json_data)
