@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Sensors API wrapper.
+"""Cisco DNA Center Sensors API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class Sensors(object):
-    """DNA Center Sensors API (version: 2.2.1).
+    """Cisco DNA Center Sensors API (version: 2.1.2).
 
     Wraps the DNA Center Sensors
     API and exposes the API as native Python
@@ -86,15 +86,11 @@ class Sensors(object):
         existing SSID, or both new and existing SSID.
 
         Args:
-            apCoverage(list): Ap Coverage, property of the request
-                body (list of objects).
-            connection(string): Connection, property of the request
-                body.
-            modelVersion(number): modelVersion, property of the
-                request body.
+            apCoverage(list): Ap Coverage, property of the request body (list of objects).
+            connection(string): Connection, property of the request body.
+            modelVersion(number): modelVersion, property of the request body.
             name(string): Name, property of the request body.
-            ssids(list): Ssids, property of the request body (list
-                of objects).
+            ssids(list): Ssids, property of the request body (list of objects).
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -143,7 +139,7 @@ class Sensors(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_08bd88834a68a2e6_v2_2_1')\
+            self._request_validator('jsd_08bd88834a68a2e6_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -162,7 +158,7 @@ class Sensors(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_08bd88834a68a2e6_v2_2_1', json_data)
+        return self._object_factory('bpm_08bd88834a68a2e6_v2_1_2', json_data)
 
     def delete_sensor_test(self,
                            template_name=None,
@@ -217,7 +213,82 @@ class Sensors(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_5bbb28ff442a825f_v2_2_1', json_data)
+        return self._object_factory('bpm_5bbb28ff442a825f_v2_1_2', json_data)
+
+    def duplicate_sensor_test_template(self,
+                                       newTemplateName=None,
+                                       templateName=None,
+                                       headers=None,
+                                       payload=None,
+                                       active_validation=True,
+                                       **request_parameters):
+        """Intent API to duplicate an existing SENSOR test template.
+
+        Args:
+            newTemplateName(string): New Template Name, property of the request body.
+            templateName(string): Template Name, property of the request body.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = {
+            'templateName':
+                templateName,
+            'newTemplateName':
+                newTemplateName,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_85a2883749099021_v2_1_2')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/sensorTestTemplate')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_85a2883749099021_v2_1_2', json_data)
 
     def sensors(self,
                 site_id=None,
@@ -272,84 +343,7 @@ class Sensors(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_71a12bb745699cc5_v2_2_1', json_data)
-
-    def duplicate_sensor_test_template(self,
-                                       newTemplateName=None,
-                                       templateName=None,
-                                       headers=None,
-                                       payload=None,
-                                       active_validation=True,
-                                       **request_parameters):
-        """Intent API to duplicate an existing SENSOR test template.
-
-        Args:
-            newTemplateName(string): New Template Name, property of
-                the request body.
-            templateName(string): Template Name, property of the
-                request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'templateName':
-                templateName,
-            'newTemplateName':
-                newTemplateName,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_85a2883749099021_v2_2_1')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/sensorTestTemplate')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_85a2883749099021_v2_2_1', json_data)
+        return self._object_factory('bpm_71a12bb745699cc5_v2_1_2', json_data)
 
     def edit_sensor_test_template(self,
                                   locationInfoList=None,
@@ -363,12 +357,9 @@ class Sensors(object):
         template.
 
         Args:
-            locationInfoList(list): Location Info List, property of
-                the request body (list of objects).
-            schedule(object): Schedule, property of the request
-                body.
-            templateName(string): Template Name, property of the
-                request body.
+            locationInfoList(list): Location Info List, property of the request body (list of objects).
+            schedule(object): Schedule, property of the request body.
+            templateName(string): Template Name, property of the request body.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -413,7 +404,7 @@ class Sensors(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_c085eaf54f89ba34_v2_2_1')\
+            self._request_validator('jsd_c085eaf54f89ba34_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -432,7 +423,7 @@ class Sensors(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_c085eaf54f89ba34_v2_2_1', json_data)
+        return self._object_factory('bpm_c085eaf54f89ba34_v2_1_2', json_data)
 
     def run_now_sensor_test(self,
                             templateName=None,
@@ -443,8 +434,7 @@ class Sensors(object):
         """Intent API to run a deployed SENSOR test.
 
         Args:
-            templateName(string): Template Name, property of the
-                request body.
+            templateName(string): Template Name, property of the request body.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -485,7 +475,7 @@ class Sensors(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_f1a7a8e74cf99c8f_v2_2_1')\
+            self._request_validator('jsd_f1a7a8e74cf99c8f_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -504,4 +494,4 @@ class Sensors(object):
             json_data = self._session.put(endpoint_full_url, params=_params,
                                           json=_payload)
 
-        return self._object_factory('bpm_f1a7a8e74cf99c8f_v2_2_1', json_data)
+        return self._object_factory('bpm_f1a7a8e74cf99c8f_v2_1_2', json_data)
