@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Wireless API wrapper.
+"""Cisco DNA Center Wireless API wrapper.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ from ...utils import (
 
 
 class Wireless(object):
-    """DNA Center Wireless API (version: 2.1.1).
+    """Cisco DNA Center Wireless API (version: 2.1.2).
 
     Wraps the DNA Center Wireless
     API and exposes the API as native Python
@@ -79,8 +79,7 @@ class Wireless(object):
         """Retrieve all RF profiles.
 
         Args:
-            rf_profile_name(basestring): rf-profile-name query
-                parameter.
+            rf_profile_name(basestring): rf-profile-name query parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -126,7 +125,7 @@ class Wireless(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_098cab9141c9a3fe_v2_1_1', json_data)
+        return self._object_factory('bpm_098cab9141c9a3fe_v2_1_2', json_data)
 
     def create_and_provision_ssid(self,
                                   enableFabric=None,
@@ -143,18 +142,12 @@ class Wireless(object):
         given sites.
 
         Args:
-            enableFabric(boolean): enableFabric, property of the
-                request body.
-            flexConnect(object): Flex Connect - Applicable for non
-                fabric profile, property of the request
-                body.
-            managedAPLocations(list): Managed AP Locations (Enter
-                entire Site(s) hierarchy), property of
-                the request body (list of strings).
-            ssidDetails(object): SsidDetails, property of the
-                request body.
-            ssidType(string): SSID Type, property of the request
-                body. Available values are 'Guest' and
+            enableFabric(boolean): enableFabric, property of the request body.
+            flexConnect(object): Flex Connect Applicable for non fabric profile, property of the request body.
+            managedAPLocations(list): Managed AP Locations (Enter entire Site(s) hierarchy), property of the request
+                body (list of strings).
+            ssidDetails(object): SsidDetails, property of the request body.
+            ssidType(string): SSID Type, property of the request body. Available values are 'Guest' and
                 'Enterprise'.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
@@ -207,7 +200,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_1eb72ad34e098990_v2_1_1')\
+            self._request_validator('jsd_1eb72ad34e098990_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -226,7 +219,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_1eb72ad34e098990_v2_1_1', json_data)
+        return self._object_factory('bpm_1eb72ad34e098990_v2_1_2', json_data)
 
     def delete_rf_profiles(self,
                            rf_profile_name,
@@ -235,8 +228,7 @@ class Wireless(object):
         """Delete RF profile(s).
 
         Args:
-            rf_profile_name(basestring): rf-profile-name path
-                parameter.
+            rf_profile_name(basestring): rf-profile-name path parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -283,7 +275,7 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_28b24a744a9994be_v2_1_1', json_data)
+        return self._object_factory('bpm_28b24a744a9994be_v2_1_2', json_data)
 
     def create_wireless_profile(self,
                                 profileDetails=None,
@@ -295,8 +287,7 @@ class Wireless(object):
         and SSIDs to it.
 
         Args:
-            profileDetails(object): Profile Details, property of the
-                request body.
+            profileDetails(object): Profile Details, property of the request body.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -337,7 +328,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_709769624bf988d5_v2_1_1')\
+            self._request_validator('jsd_709769624bf988d5_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -356,22 +347,24 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_709769624bf988d5_v2_1_1', json_data)
+        return self._object_factory('bpm_709769624bf988d5_v2_1_2', json_data)
 
-    def provision_update(self,
-                         headers=None,
-                         payload=None,
-                         active_validation=True,
-                         **request_parameters):
-        """Updates wireless provisioning.
+    def sensor_test_results(self,
+                            end_time=None,
+                            site_id=None,
+                            start_time=None,
+                            test_failure_by='area',
+                            headers=None,
+                            **request_parameters):
+        """Intent API to get SENSOR test result summary.
 
         Args:
+            site_id(basestring): Assurance site UUID.
+            start_time(int): The epoch time in milliseconds.
+            end_time(int): The epoch time in milliseconds.
+            test_failure_by(basestring): Obtain failure statistics group by "area", "building", or "floor".
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
             **request_parameters: Additional request parameters (provides
                 support for parameters that may be added in the future).
 
@@ -385,16 +378,24 @@ class Wireless(object):
             ApiError: If the DNA Center cloud returns an error.
         """
         check_type(headers, dict)
-        check_type(payload, list)
+        check_type(site_id, basestring)
+        check_type(start_time, int)
+        check_type(end_time, int)
+        check_type(test_failure_by, basestring)
         if headers is not None:
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           basestring, may_be_none=False)
             if 'X-Auth-Token' in headers:
                 check_type(headers.get('X-Auth-Token'),
                            basestring, may_be_none=False)
 
         _params = {
+            'siteId':
+                site_id,
+            'startTime':
+                start_time,
+            'endTime':
+                end_time,
+            'testFailureBy':
+                test_failure_by,
         }
         _params.update(request_parameters)
         _params = dict_from_items_with_values(_params)
@@ -402,28 +403,21 @@ class Wireless(object):
         path_params = {
         }
 
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_87a5ab044139862d_v2_1_1')\
-                .validate(_payload)
-
         with_custom_headers = False
         _headers = self._session.headers or {}
         if headers:
             _headers.update(dict_of_str(headers))
             with_custom_headers = True
 
-        e_url = ('/dna/intent/api/v1/wireless/provision')
+        e_url = ('/dna/intent/api/v1/AssuranceGetSensorTestResults')
         endpoint_full_url = apply_path_params(e_url, path_params)
         if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
+            json_data = self._session.get(endpoint_full_url, params=_params,
                                           headers=_headers)
         else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
+            json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_87a5ab044139862d_v2_1_1', json_data)
+        return self._object_factory('bpm_87ae7b214f0ba838_v2_1_2', json_data)
 
     def create_enterprise_ssid(self,
                                enableBroadcastSSID=None,
@@ -442,34 +436,21 @@ class Wireless(object):
         """Creates enterprise SSID.
 
         Args:
-            enableBroadcastSSID(boolean): enableBroadcastSSID,
-                property of the request body.
-            enableFastLane(boolean): enableFastLane, property of the
-                request body.
-            enableMACFiltering(boolean): enableMACFiltering,
-                property of the request body.
-            fastTransition(string): Fast Transition, property of the
-                request body. Available values are
-                'Adaptive', 'Enable' and 'Disable'.
-            name(string): Enter SSID Name, property of the request
-                body. Constraints: maxLength set to 32.
-            passphrase(string): Pass Phrase (Only applicable for
-                SSID with PERSONAL security level),
-                property of the request body.
-                Constraints: maxLength set to 63 and
-                minLength set to 8.
-            radioPolicy(string): Radio Policy, property of the
-                request body. Available values are 'Dual
-                band operation (2.4GHz and 5GHz)', 'Dual
-                band operation with band select', '5GHz
-                only' and '2.4GHz only'.
-            securityLevel(string): Security Level, property of the
-                request body. Available values are
-                'WPA2_ENTERPRISE', 'WPA2_PERSONAL' and
-                'OPEN'.
-            trafficType(string): Traffic Type, property of the
-                request body. Available values are
-                'voicedata' and 'data'.
+            enableBroadcastSSID(boolean): enableBroadcastSSID, property of the request body.
+            enableFastLane(boolean): enableFastLane, property of the request body.
+            enableMACFiltering(boolean): enableMACFiltering, property of the request body.
+            fastTransition(string): Fast Transition, property of the request body. Available values are 'Adaptive',
+                'Enable' and 'Disable'.
+            name(string): Enter SSID Name, property of the request body. Constraints: maxLength set to 32.
+            passphrase(string): Pass Phrase (Only applicable for SSID with PERSONAL security level), property of the
+                request body. Constraints: maxLength set to 63 and minLength set to 8.
+            radioPolicy(string): Radio Policy, property of the request body. Available values are 'Dual band
+                operation (2.4GHz and 5GHz)', 'Dual band operation with band select', '5GHz only' and
+                '2.4GHz only'.
+            securityLevel(string): Security Level, property of the request body. Available values are
+                'WPA2_ENTERPRISE', 'WPA2_PERSONAL' and 'OPEN'.
+            trafficType(string): Traffic Type, property of the request body. Available values are 'voicedata' and
+                'data'.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -526,7 +507,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_8a96fb954d09a349_v2_1_1')\
+            self._request_validator('jsd_8a96fb954d09a349_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -545,7 +526,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_8a96fb954d09a349_v2_1_1', json_data)
+        return self._object_factory('bpm_8a96fb954d09a349_v2_1_2', json_data)
 
     def get_wireless_profile(self,
                              profile_name=None,
@@ -602,7 +583,7 @@ class Wireless(object):
         else:
             json_data = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_b3a1c8804c8b9b8b_v2_1_1', json_data)
+        return self._object_factory('bpm_b3a1c8804c8b9b8b_v2_1_2', json_data)
 
     def create_or_update_rf_profile(self,
                                     channelWidth=None,
@@ -621,23 +602,15 @@ class Wireless(object):
         """Create or Update RF profile.
 
         Args:
-            channelWidth(string): Channel Width, property of the
-                request body.
-            defaultRfProfile(boolean): defaultRfProfile, property of
-                the request body.
-            enableBrownField(boolean): enableBrownField, property of
-                the request body.
-            enableCustom(boolean): enableCustom, property of the
-                request body.
-            enableRadioTypeA(boolean): enableRadioTypeA, property of
-                the request body.
-            enableRadioTypeB(boolean): enableRadioTypeB, property of
-                the request body.
+            channelWidth(string): Channel Width, property of the request body.
+            defaultRfProfile(boolean): defaultRfProfile, property of the request body.
+            enableBrownField(boolean): enableBrownField, property of the request body.
+            enableCustom(boolean): enableCustom, property of the request body.
+            enableRadioTypeA(boolean): enableRadioTypeA, property of the request body.
+            enableRadioTypeB(boolean): enableRadioTypeB, property of the request body.
             name(string): Name, property of the request body.
-            radioTypeAProperties(object): Radio Type AProperties,
-                property of the request body.
-            radioTypeBProperties(object): Radio Type BProperties,
-                property of the request body.
+            radioTypeAProperties(object): Radio Type AProperties, property of the request body.
+            radioTypeBProperties(object): Radio Type BProperties, property of the request body.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             payload(dict): A JSON serializable Python object to send in the
@@ -694,7 +667,7 @@ class Wireless(object):
         _payload.update(payload or {})
         _payload = dict_from_items_with_values(_payload)
         if active_validation:
-            self._request_validator('jsd_b78329674878b815_v2_1_1')\
+            self._request_validator('jsd_b78329674878b815_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -713,7 +686,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_b78329674878b815_v2_1_1', json_data)
+        return self._object_factory('bpm_b78329674878b815_v2_1_2', json_data)
 
     def delete_enterprise_ssid(self,
                                ssid_name,
@@ -722,8 +695,7 @@ class Wireless(object):
         """Deletes given enterprise SSID.
 
         Args:
-            ssid_name(basestring): Enter the SSID name to be
-                deleted.
+            ssid_name(basestring): Enter the SSID name to be deleted.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -769,7 +741,131 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_c7a6592b4b98a369_v2_1_1', json_data)
+        return self._object_factory('bpm_c7a6592b4b98a369_v2_1_2', json_data)
+
+    def provision_update(self,
+                         headers=None,
+                         payload=None,
+                         active_validation=True,
+                         **request_parameters):
+        """Updates wireless provisioning.
+
+        Args:
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(list): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, list)
+        if headers is not None:
+            if '__persistbapioutput' in headers:
+                check_type(headers.get('__persistbapioutput'),
+                           basestring, may_be_none=False)
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = payload or []
+        if active_validation:
+            self._request_validator('jsd_87a5ab044139862d_v2_1_2')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/wireless/provision')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_87a5ab044139862d_v2_1_2', json_data)
+
+    def get_enterprise_ssid(self,
+                            ssid_name=None,
+                            headers=None,
+                            **request_parameters):
+        """Gets either one or all the enterprise SSID.
+
+        Args:
+            ssid_name(basestring): Enter the enterprise SSID name that needs to be retrieved. If not entered, all
+                the enterprise SSIDs will be retrieved.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            list: JSON response. A list of MyDict objects.
+            Access the object's properties by using the dot notation
+            or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(ssid_name, basestring)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+            'ssidName':
+                ssid_name,
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/enterprise-ssid')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.get(endpoint_full_url, params=_params,
+                                          headers=_headers)
+        else:
+            json_data = self._session.get(endpoint_full_url, params=_params)
+
+        return self._object_factory('bpm_cca519ba45ebb423_v2_1_2', json_data)
 
     def provision(self,
                   headers=None,
@@ -817,7 +913,7 @@ class Wireless(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_d09b08a3447aa3b9_v2_1_1')\
+            self._request_validator('jsd_d09b08a3447aa3b9_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -836,66 +932,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_d09b08a3447aa3b9_v2_1_1', json_data)
-
-    def get_enterprise_ssid(self,
-                            ssid_name=None,
-                            headers=None,
-                            **request_parameters):
-        """Gets either one or all the enterprise SSID.
-
-        Args:
-            ssid_name(basestring): Enter the enterprise SSID name
-                that needs to be retrieved. If not
-                entered, all the enterprise SSIDs will
-                be retrieved.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            list: JSON response. A list of MyDict objects.
-            Access the object's properties by using the dot notation
-            or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(ssid_name, basestring)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-            'ssidName':
-                ssid_name,
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/enterprise-ssid')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.get(endpoint_full_url, params=_params,
-                                          headers=_headers)
-        else:
-            json_data = self._session.get(endpoint_full_url, params=_params)
-
-        return self._object_factory('bpm_cca519ba45ebb423_v2_1_1', json_data)
+        return self._object_factory('bpm_d09b08a3447aa3b9_v2_1_2', json_data)
 
     def ap_provision(self,
                      headers=None,
@@ -943,7 +980,7 @@ class Wireless(object):
 
         _payload = payload or []
         if active_validation:
-            self._request_validator('jsd_e9b99b2248c88014_v2_1_1')\
+            self._request_validator('jsd_e9b99b2248c88014_v2_1_2')\
                 .validate(_payload)
 
         with_custom_headers = False
@@ -962,148 +999,7 @@ class Wireless(object):
             json_data = self._session.post(endpoint_full_url, params=_params,
                                            json=_payload)
 
-        return self._object_factory('bpm_e9b99b2248c88014_v2_1_1', json_data)
-
-    def ap_provision_and_re_provision(self,
-                                      headers=None,
-                                      payload=None,
-                                      active_validation=True,
-                                      **request_parameters):
-        """Access Point Provision and ReProvision .
-
-        Args:
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(list): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, list)
-        if headers is not None:
-            if '__persistbapioutput' in headers:
-                check_type(headers.get('__persistbapioutput'),
-                           basestring)
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = payload or []
-        if active_validation:
-            self._request_validator('jsd_d89719b847aaa9c4_v2_1_1')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/wireless/ap-provision')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload,
-                                           headers=_headers)
-        else:
-            json_data = self._session.post(endpoint_full_url, params=_params,
-                                           json=_payload)
-
-        return self._object_factory('bpm_d89719b847aaa9c4_v2_1_1', json_data)
-
-    def update_wireless_profile(self,
-                                profileDetails=None,
-                                headers=None,
-                                payload=None,
-                                active_validation=True,
-                                **request_parameters):
-        """Updates the wireless Network Profile with updated details
-        provided. All sites to be present in the network profile
-        should be provided.
-
-        Args:
-            profileDetails(object): Profile Details, property of the
-                request body.
-            headers(dict): Dictionary of HTTP Headers to send with the Request
-                .
-            payload(dict): A JSON serializable Python object to send in the
-                body of the Request.
-            active_validation(bool): Enable/Disable payload validation.
-                Defaults to True.
-            **request_parameters: Additional request parameters (provides
-                support for parameters that may be added in the future).
-
-        Returns:
-            MyDict: JSON response. Access the object's properties by using
-            the dot notation or the bracket notation.
-
-        Raises:
-            TypeError: If the parameter types are incorrect.
-            MalformedRequest: If the request body created is invalid.
-            ApiError: If the DNA Center cloud returns an error.
-        """
-        check_type(headers, dict)
-        check_type(payload, dict)
-        if headers is not None:
-            if 'X-Auth-Token' in headers:
-                check_type(headers.get('X-Auth-Token'),
-                           basestring, may_be_none=False)
-
-        _params = {
-        }
-        _params.update(request_parameters)
-        _params = dict_from_items_with_values(_params)
-
-        path_params = {
-        }
-
-        _payload = {
-            'profileDetails':
-                profileDetails,
-        }
-        _payload.update(payload or {})
-        _payload = dict_from_items_with_values(_payload)
-        if active_validation:
-            self._request_validator('jsd_cfbd3870405aad55_v2_1_1')\
-                .validate(_payload)
-
-        with_custom_headers = False
-        _headers = self._session.headers or {}
-        if headers:
-            _headers.update(dict_of_str(headers))
-            with_custom_headers = True
-
-        e_url = ('/dna/intent/api/v1/wireless/profile')
-        endpoint_full_url = apply_path_params(e_url, path_params)
-        if with_custom_headers:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload,
-                                          headers=_headers)
-        else:
-            json_data = self._session.put(endpoint_full_url, params=_params,
-                                          json=_payload)
-
-        return self._object_factory('bpm_cfbd3870405aad55_v2_1_1', json_data)
+        return self._object_factory('bpm_e9b99b2248c88014_v2_1_2', json_data)
 
     def delete_wireless_profile(self,
                                 wireless_profile_name,
@@ -1112,8 +1008,7 @@ class Wireless(object):
         """Delete the Wireless Profile from DNAC whose name is provided.
 
         Args:
-            wireless_profile_name(basestring): wirelessProfileName
-                path parameter.
+            wireless_profile_name(basestring): wirelessProfileName path parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -1160,7 +1055,80 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e39588a5494982c4_v2_1_1', json_data)
+        return self._object_factory('bpm_e39588a5494982c4_v2_1_2', json_data)
+
+    def update_wireless_profile(self,
+                                profileDetails=None,
+                                headers=None,
+                                payload=None,
+                                active_validation=True,
+                                **request_parameters):
+        """Updates the wireless Network Profile with updated details
+        provided. All sites to be present in the network profile
+        should be provided.
+
+        Args:
+            profileDetails(object): Profile Details, property of the request body.
+            headers(dict): Dictionary of HTTP Headers to send with the Request
+                .
+            payload(dict): A JSON serializable Python object to send in the
+                body of the Request.
+            active_validation(bool): Enable/Disable payload validation.
+                Defaults to True.
+            **request_parameters: Additional request parameters (provides
+                support for parameters that may be added in the future).
+
+        Returns:
+            MyDict: JSON response. Access the object's properties by using
+            the dot notation or the bracket notation.
+
+        Raises:
+            TypeError: If the parameter types are incorrect.
+            MalformedRequest: If the request body created is invalid.
+            ApiError: If the DNA Center cloud returns an error.
+        """
+        check_type(headers, dict)
+        check_type(payload, dict)
+        if headers is not None:
+            if 'X-Auth-Token' in headers:
+                check_type(headers.get('X-Auth-Token'),
+                           basestring, may_be_none=False)
+
+        _params = {
+        }
+        _params.update(request_parameters)
+        _params = dict_from_items_with_values(_params)
+
+        path_params = {
+        }
+
+        _payload = {
+            'profileDetails':
+                profileDetails,
+        }
+        _payload.update(payload or {})
+        _payload = dict_from_items_with_values(_payload)
+        if active_validation:
+            self._request_validator('jsd_cfbd3870405aad55_v2_1_2')\
+                .validate(_payload)
+
+        with_custom_headers = False
+        _headers = self._session.headers or {}
+        if headers:
+            _headers.update(dict_of_str(headers))
+            with_custom_headers = True
+
+        e_url = ('/dna/intent/api/v1/wireless/profile')
+        endpoint_full_url = apply_path_params(e_url, path_params)
+        if with_custom_headers:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload,
+                                          headers=_headers)
+        else:
+            json_data = self._session.put(endpoint_full_url, params=_params,
+                                          json=_payload)
+
+        return self._object_factory('bpm_cfbd3870405aad55_v2_1_2', json_data)
 
     def delete_ssid_and_provision_it_to_devices(self,
                                                 managed_aplocations,
@@ -1172,8 +1140,7 @@ class Wireless(object):
 
         Args:
             ssid_name(basestring): ssidName path parameter.
-            managed_aplocations(basestring): managedAPLocations path
-                parameter.
+            managed_aplocations(basestring): managedAPLocations path parameter.
             headers(dict): Dictionary of HTTP Headers to send with the Request
                 .
             **request_parameters: Additional request parameters (provides
@@ -1226,4 +1193,4 @@ class Wireless(object):
         else:
             json_data = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_fc9538fe43d9884d_v2_1_1', json_data)
+        return self._object_factory('bpm_fc9538fe43d9884d_v2_1_2', json_data)
