@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Provision NFV data model.
+"""Cisco DNA Center Provision NFV data model.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -44,40 +44,34 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
         self._validator = fastjsonschema.compile(json.loads(
             '''{
                 "properties": {
+                "callbackUrl": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
                 "provisioning": {
-                "description":
-                "Provisioning",
                 "items": {
                 "properties": {
                 "device": {
-                "description":
-                "Device",
                 "items": {
                 "properties": {
                 "customNetworks": {
-                "description":
-                "Custom Networks",
                 "items": {
                 "properties": {
                 "ipAddressPool": {
-                "description":
-                "Ip Address Pool",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "port": {
-                "description":
-                "Port",
                 "type": [
                 "string",
                 "null"
@@ -95,73 +89,53 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "deviceSerialNumber": {
-                "description":
-                "Device Serial Number",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ip": {
-                "description":
-                "Ip",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "serviceProviders": {
-                "description":
-                "Service Providers",
                 "items": {
                 "properties": {
                 "serviceProvider": {
-                "description":
-                "Service Provider",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "wanInterface": {
-                "description":
-                "Wan Interface",
                 "properties": {
                 "bandwidth": {
-                "description":
-                "Bandwidth",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "gateway": {
-                "description":
-                "Gateway",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "interfaceName": {
-                "description":
-                "Interface Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ipAddress": {
-                "description":
-                "Ip Address",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "subnetmask": {
-                "description":
-                "Subnetmask",
                 "type": [
                 "string",
                 "null"
@@ -185,61 +159,45 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "services": {
-                "description":
-                "Services",
                 "items": {
                 "properties": {
                 "adminPasswordHash": {
-                "description":
-                "Admin Password Hash",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "centralManagerIP": {
-                "description":
-                "Central Manager IP",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "centralRegistrationKey": {
-                "description":
-                "Central Registration Key",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "commonKey": {
-                "description":
-                "Common Key",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "mode": {
-                "description":
-                "Mode",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "systemIp": {
-                "description":
-                "System Ip",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -257,45 +215,27 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "subPools": {
-                "description":
-                "Sub Pools",
                 "items": {
                 "properties": {
                 "gateway": {
-                "description":
-                "Gateway",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ipSubnet": {
-                "description":
-                "Ip Subnet",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "parentPoolName": {
-                "description":
-                "Parent Pool Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "enum": [
                 "Lan",
                 "Management",
@@ -321,91 +261,33 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "tagName": {
-                "description":
-                "Tag Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
-                "templateParam": {
-                "description":
-                "Template Param",
-                "properties": {
-                "asav": {
-                "description":
-                "Asav",
-                "properties": {
-                "var1": {
-                "description":
-                "Var1",
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
-                "nfvis": {
-                "description":
-                "Nfvis",
-                "properties": {
-                "var1": {
-                "description":
-                "Var1",
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
                 "vlan": {
-                "description":
-                "Vlan",
                 "items": {
                 "properties": {
                 "id": {
-                "description":
-                "Id",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "interfaces": {
-                "description":
-                "Interfaces",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "network": {
-                "description":
-                "Network",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -433,25 +315,47 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "null"
                 ]
                 },
-                "site": {
-                "description":
-                "Site",
+                "networksettings": {
                 "properties": {
+                "ipPool": {
+                "properties": {
+                "globalPool": {
+                "properties": {
+                "name": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "site": {
+                "properties": {
                 "area": {
-                "description":
-                "Area",
                 "properties": {
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
@@ -464,40 +368,14 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "building": {
-                "description":
-                "Building",
                 "properties": {
                 "address": {
-                "description":
-                "Address",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
-                "latitude": {
-                "type": [
-                "number",
-                "null"
-                ]
-                },
-                "longitude": {
-                "type": [
-                "number",
-                "null"
-                ]
-                },
                 "name": {
-                "description":
-                "Name",
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
@@ -510,50 +388,18 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "floor": {
-                "description":
-                "Floor",
                 "properties": {
-                "height": {
-                "type": [
-                "number",
-                "null"
-                ]
-                },
-                "length": {
-                "type": [
-                "number",
-                "null"
-                ]
-                },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
                 ]
-                },
-                "rfModel": {
-                "description":
-                "Rf Model",
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "width": {
-                "type": [
-                "number",
-                "null"
-                ]
                 }
                 },
                 "type": [
@@ -562,8 +408,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "siteProfileName": {
-                "description":
-                "Site Profile Name",
                 "type": [
                 "string",
                 "null"
@@ -574,6 +418,42 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 "object",
                 "null"
                 ]
+                },
+                "templateParam": {
+                "properties": {
+                "asav": {
+                "properties": {
+                "var1": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "nfvis": {
+                "properties": {
+                "var1": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
                 }
                 },
                 "type": [
@@ -586,52 +466,67 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "siteProfile": {
-                "description":
-                "Site Profile",
                 "items": {
                 "properties": {
+                "customTemplate": {
+                "items": {
+                "properties": {
+                "deviceType": {
+                "enum": [
+                "NFVIS",
+                "ASAv",
+                null
+                ],
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "template": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "type": [
+                "array",
+                "null"
+                ]
+                },
                 "device": {
-                "description":
-                "Device",
                 "items": {
                 "properties": {
                 "customNetworks": {
-                "description":
-                "Custom Networks",
                 "items": {
                 "properties": {
                 "connectionType": {
-                "description":
-                "Connection Type",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "networkMode": {
-                "description":
-                "Network Mode",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "servicesToConnect": {
-                "description":
-                "Services To Connect",
                 "items": {
                 "properties": {
                 "service": {
-                "description":
-                "Service",
                 "type": [
                 "string",
                 "null"
@@ -649,8 +544,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "vlan": {
-                "description":
-                "Vlan",
                 "type": [
                 "string",
                 "null"
@@ -668,66 +561,21 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "customServices": {
-                "description":
-                "Custom Services",
                 "items": {
                 "properties": {
                 "applicationType": {
-                "description":
-                "Application Type",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "profile": {
-                "description":
-                "Profile",
-                "type": [
-                "string",
-                "null"
-                ]
-                }
-                },
-                "type": [
-                "object",
-                "null"
-                ]
-                },
-                "type": [
-                "array",
-                "null"
-                ]
-                },
-                "customTemplate": {
-                "description":
-                "Custom Template",
-                "items": {
-                "properties": {
-                "deviceType": {
-                "description":
-                "Device Type",
-                "enum": [
-                "NFVIS",
-                "ASAv",
-                null
-                ],
-                "type": [
-                "string",
-                "null"
-                ]
-                },
-                "template": {
-                "description":
-                "Template",
                 "type": [
                 "string",
                 "null"
@@ -745,8 +593,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "deviceType": {
-                "description":
-                "Device Type",
                 "enum": [
                 "ENCS5100",
                 "ENCS5400",
@@ -764,8 +610,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "serviceProviders": {
-                "description":
-                "Service Providers",
                 "items": {
                 "properties": {
                 "connect": {
@@ -781,8 +625,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "linkType": {
-                "description":
-                "Link Type",
                 "enum": [
                 "GigabitEthernet",
                 null
@@ -793,8 +635,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "serviceProvider": {
-                "description":
-                "Service Provider",
                 "type": [
                 "string",
                 "null"
@@ -812,29 +652,21 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "services": {
-                "description":
-                "Services",
                 "items": {
                 "properties": {
                 "mode": {
-                "description":
-                "Mode",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "profile": {
-                "description":
-                "Profile",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "enum": [
                 "isr",
                 "vedge",
@@ -865,29 +697,21 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "tagName": {
-                "description":
-                "Tag Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "vlan": {
-                "description":
-                "Vlan",
                 "items": {
                 "properties": {
                 "id": {
-                "description":
-                "Id",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -916,8 +740,6 @@ class JSONSchemaValidator828828F44F28Bd0D(object):
                 ]
                 },
                 "siteProfileName": {
-                "description":
-                "Site Profile Name",
                 "type": [
                 "string",
                 "null"
