@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Import Devices in bulk data model.
+"""Cisco DNA Center Import Devices in bulk data model.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -46,8 +46,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "_id": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -58,16 +56,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "aaaCredentials": {
                 "properties": {
                 "password": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "username": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -98,8 +92,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "agentType": {
-                "description":
-                 "",
                 "enum": [
                 "POSIX",
                 "IOS",
@@ -111,16 +103,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "authStatus": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "authenticatedSudiSerialNo": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -139,8 +127,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "cmState": {
-                "description":
-                 "",
                 "enum": [
                 "NotContacted",
                 "Contacted",
@@ -159,8 +145,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 },
                 "description":
                  {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -179,8 +163,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "deviceType": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -208,8 +190,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -228,8 +208,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -259,8 +237,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "hostname": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -270,16 +246,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "key": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "value": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null",
@@ -298,16 +270,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "imageFile": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "imageVersion": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -329,24 +297,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "macAddress": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "status": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -384,24 +346,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "location": {
                 "properties": {
                 "address": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "altitude": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "latitude": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null",
@@ -409,8 +365,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "longitude": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null",
@@ -418,8 +372,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "siteId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -432,24 +384,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "macAddress": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "mode": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -459,72 +405,54 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "localInterfaceName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "localMacAddress": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "localShortInterfaceName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remoteDeviceName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remoteInterfaceName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remoteMacAddress": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remotePlatform": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remoteShortInterfaceName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "remoteVersion": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -542,8 +470,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "onbState": {
-                "description":
-                 "",
                 "enum": [
                 "NotContacted",
                 "Connecting",
@@ -568,8 +494,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "pid": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -579,8 +503,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "createdBy": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -595,16 +517,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "primaryEndpoint": {
                 "properties": {
                 "certificate": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "fqdn": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -619,8 +537,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "protocol": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -633,8 +549,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "profileName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -643,16 +557,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "secondaryEndpoint": {
                 "properties": {
                 "certificate": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "fqdn": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -667,8 +577,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "protocol": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -701,16 +609,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "cli": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "cliOutput": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -728,16 +632,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "projectId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "projectName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -750,24 +650,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "serialNumber": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "smartAccountId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "source": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -791,40 +685,30 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "hardwareVersion": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "licenseLevel": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "licenseType": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "macAddress": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "pid": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -837,24 +721,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "role": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "serialNumber": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "softwareVersion": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -867,16 +745,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "sudiSerialNumber": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -894,8 +768,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "stackRingProtocol": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -932,8 +804,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "enum": [
                 "Unclaimed",
                 "Planned",
@@ -968,24 +838,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "virtualAccountId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "workflowId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "workflowName": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1001,8 +865,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "details": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1020,16 +882,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "key": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "value": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null",
@@ -1048,8 +906,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1062,8 +918,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1073,8 +927,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "command": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1087,8 +939,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "outputStr": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1101,8 +951,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1151,8 +999,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "systemResetWorkflow": {
                 "properties": {
                 "_id": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1171,8 +1017,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "configId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1186,8 +1030,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 },
                 "description":
                  {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1206,16 +1048,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "imageId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "instanceType": {
-                "description":
-                 "",
                 "enum": [
                 "SystemWorkflow",
                 "UserWorkflow",
@@ -1234,8 +1072,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1248,8 +1084,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1271,8 +1105,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1285,8 +1117,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1305,8 +1135,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1316,8 +1144,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "command": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1330,8 +1156,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "outputStr": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1344,8 +1168,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1380,24 +1202,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "tenantId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "useState": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1418,8 +1234,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "systemWorkflow": {
                 "properties": {
                 "_id": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1438,8 +1252,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "configId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1453,8 +1265,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 },
                 "description":
                  {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1473,16 +1283,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "imageId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "instanceType": {
-                "description":
-                 "",
                 "enum": [
                 "SystemWorkflow",
                 "UserWorkflow",
@@ -1501,8 +1307,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1515,8 +1319,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1538,8 +1340,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1552,8 +1352,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1572,8 +1370,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1583,8 +1379,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "command": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1597,8 +1391,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "outputStr": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1611,8 +1403,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1647,24 +1437,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "tenantId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "useState": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1683,8 +1467,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "tenantId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1699,8 +1481,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "workflow": {
                 "properties": {
                 "_id": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1719,8 +1499,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "configId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1734,8 +1512,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 },
                 "description":
                  {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1754,16 +1530,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "imageId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "instanceType": {
-                "description":
-                 "",
                 "enum": [
                 "SystemWorkflow",
                 "UserWorkflow",
@@ -1782,8 +1554,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1796,8 +1566,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1819,8 +1587,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "name": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1833,8 +1599,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1853,8 +1617,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1864,8 +1626,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "command": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1878,8 +1638,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "outputStr": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1892,8 +1650,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "state": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1928,24 +1684,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "tenantId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "useState": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1969,8 +1719,6 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "configId": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
@@ -1980,16 +1728,12 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 "items": {
                 "properties": {
                 "key": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "value": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null",
@@ -2019,24 +1763,18 @@ class JSONSchemaValidator21A6Db2540298F55(object):
                 ]
                 },
                 "licenseLevel": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "licenseType": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "topOfStackSerialNumber": {
-                "description":
-                 "",
                 "type": [
                 "string",
                 "null"
