@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""DNA Center Provision NFV data model.
+"""Cisco DNA Center Provision NFV data model.
 
-Copyright (c) 2019-2020 Cisco and/or its affiliates.
+Copyright (c) 2019-2021 Cisco Systems.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -45,39 +45,27 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
             '''{
                 "properties": {
                 "provisioning": {
-                "description":
-                "Provisioning",
                 "items": {
                 "properties": {
                 "device": {
-                "description":
-                "Device",
                 "items": {
                 "properties": {
                 "customNetworks": {
-                "description":
-                "Custom Networks",
                 "items": {
                 "properties": {
                 "ipAddressPool": {
-                "description":
-                "Ip Address Pool",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "port": {
-                "description":
-                "Port",
                 "type": [
                 "string",
                 "null"
@@ -95,73 +83,53 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "deviceSerialNumber": {
-                "description":
-                "Device Serial Number",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ip": {
-                "description":
-                "Ip",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "serviceProviders": {
-                "description":
-                "Service Providers",
                 "items": {
                 "properties": {
                 "serviceProvider": {
-                "description":
-                "Service Provider",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "wanInterface": {
-                "description":
-                "Wan Interface",
                 "properties": {
                 "bandwidth": {
-                "description":
-                "Bandwidth",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "gateway": {
-                "description":
-                "Gateway",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "interfaceName": {
-                "description":
-                "Interface Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ipAddress": {
-                "description":
-                "Ip Address",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "subnetmask": {
-                "description":
-                "Subnetmask",
                 "type": [
                 "string",
                 "null"
@@ -185,61 +153,51 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "services": {
-                "description":
-                "Services",
                 "items": {
                 "properties": {
                 "adminPasswordHash": {
-                "description":
-                "Admin Password Hash",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "centralManagerIP": {
-                "description":
-                "Central Manager IP",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "centralRegistrationKey": {
-                "description":
-                "Central Registration Key",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "commonKey": {
-                "description":
-                "Common Key",
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "disk": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "mode": {
-                "description":
-                "Mode",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "systemIp": {
-                "description":
-                "System Ip",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -257,45 +215,33 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "subPools": {
-                "description":
-                "Sub Pools",
                 "items": {
                 "properties": {
                 "gateway": {
-                "description":
-                "Gateway",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "ipSubnet": {
-                "description":
-                "Ip Subnet",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentPoolName": {
-                "description":
-                "Parent Pool Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "enum": [
                 "Lan",
                 "Management",
@@ -321,24 +267,16 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "tagName": {
-                "description":
-                "Tag Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "templateParam": {
-                "description":
-                "Template Param",
                 "properties": {
                 "asav": {
-                "description":
-                "Asav",
                 "properties": {
                 "var1": {
-                "description":
-                "Var1",
                 "type": [
                 "string",
                 "null"
@@ -351,12 +289,8 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "nfvis": {
-                "description":
-                "Nfvis",
                 "properties": {
                 "var1": {
-                "description":
-                "Var1",
                 "type": [
                 "string",
                 "null"
@@ -375,37 +309,27 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "vlan": {
-                "description":
-                "Vlan",
                 "items": {
                 "properties": {
                 "id": {
-                "description":
-                "Id",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "interfaces": {
-                "description":
-                "Interfaces",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "network": {
-                "description":
-                "Network",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -434,24 +358,16 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "site": {
-                "description":
-                "Site",
                 "properties": {
                 "area": {
-                "description":
-                "Area",
                 "properties": {
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
@@ -464,12 +380,8 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "building": {
-                "description":
-                "Building",
                 "properties": {
                 "address": {
-                "description":
-                "Address",
                 "type": [
                 "string",
                 "null"
@@ -488,16 +400,12 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
@@ -510,8 +418,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "floor": {
-                "description":
-                "Floor",
                 "properties": {
                 "height": {
                 "type": [
@@ -526,24 +432,18 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "parentName": {
-                "description":
-                "Parent Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "rfModel": {
-                "description":
-                "Rf Model",
                 "type": [
                 "string",
                 "null"
@@ -562,8 +462,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "siteProfileName": {
-                "description":
-                "Site Profile Name",
                 "type": [
                 "string",
                 "null"
@@ -586,52 +484,36 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "siteProfile": {
-                "description":
-                "Site Profile",
                 "items": {
                 "properties": {
                 "device": {
-                "description":
-                "Device",
                 "items": {
                 "properties": {
                 "customNetworks": {
-                "description":
-                "Custom Networks",
                 "items": {
                 "properties": {
                 "connectionType": {
-                "description":
-                "Connection Type",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "networkMode": {
-                "description":
-                "Network Mode",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "servicesToConnect": {
-                "description":
-                "Services To Connect",
                 "items": {
                 "properties": {
                 "service": {
-                "description":
-                "Service",
                 "type": [
                 "string",
                 "null"
@@ -649,8 +531,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "vlan": {
-                "description":
-                "Vlan",
                 "type": [
                 "string",
                 "null"
@@ -668,33 +548,57 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "customServices": {
-                "description":
-                "Custom Services",
                 "items": {
                 "properties": {
                 "applicationType": {
-                "description":
-                "Application Type",
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "imageName": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "name": {
-                "description":
-                "Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "profile": {
-                "description":
-                "Profile",
                 "type": [
                 "string",
                 "null"
                 ]
+                },
+                "topology": {
+                "properties": {
+                "assignIp": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "name": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "type": {
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
                 }
                 },
                 "type": [
@@ -708,13 +612,9 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "customTemplate": {
-                "description":
-                "Custom Template",
                 "items": {
                 "properties": {
                 "deviceType": {
-                "description":
-                "Device Type",
                 "enum": [
                 "NFVIS",
                 "ASAv",
@@ -726,8 +626,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "template": {
-                "description":
-                "Template",
                 "type": [
                 "string",
                 "null"
@@ -745,8 +643,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "deviceType": {
-                "description":
-                "Device Type",
                 "enum": [
                 "ENCS5100",
                 "ENCS5400",
@@ -764,8 +660,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "serviceProviders": {
-                "description":
-                "Service Providers",
                 "items": {
                 "properties": {
                 "connect": {
@@ -781,8 +675,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "linkType": {
-                "description":
-                "Link Type",
                 "enum": [
                 "GigabitEthernet",
                 null
@@ -793,8 +685,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "serviceProvider": {
-                "description":
-                "Service Provider",
                 "type": [
                 "string",
                 "null"
@@ -812,29 +702,59 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "services": {
-                "description":
-                "Services",
                 "items": {
                 "properties": {
+                "imageName": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
                 "mode": {
-                "description":
-                "Mode",
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "name": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "profile": {
-                "description":
-                "Profile",
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "topology": {
+                "properties": {
+                "assignIp": {
+                "type": [
+                "string",
+                "null"
+                ]
+                },
+                "name": {
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
+                "type": [
+                "string",
+                "null"
+                ]
+                }
+                },
+                "type": [
+                "object",
+                "null"
+                ]
+                },
+                "type": {
                 "enum": [
                 "isr",
                 "vedge",
@@ -865,29 +785,21 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "tagName": {
-                "description":
-                "Tag Name",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "vlan": {
-                "description":
-                "Vlan",
                 "items": {
                 "properties": {
                 "id": {
-                "description":
-                "Id",
                 "type": [
                 "string",
                 "null"
                 ]
                 },
                 "type": {
-                "description":
-                "Type",
                 "type": [
                 "string",
                 "null"
@@ -916,8 +828,6 @@ class JSONSchemaValidator6F9CDa9A465884B4(object):
                 ]
                 },
                 "siteProfileName": {
-                "description":
-                "Site Profile Name",
                 "type": [
                 "string",
                 "null"
